=============
Documentation
=============

This part of the documentation describes how to contribute to icalendar's documentation.

For quick or small edits through the GitHub web interface, read the chapter :doc:`small-edits`.

For larger edits, the chapter :doc:`build-check` provides a comprehensive command reference to build and check the quality of documentation.

Refer to the chapter :doc:`style-guide` when you need examples of language, terminology, code, or markup.


Find issues
-----------

icalendar's documentation may have errors and omissions.
Open issues are available to work on.
Contributions to improve the documentation are welcome.
This is a good way for first-time contributors to participate in the icalendar community.

Find open issues to work on by clicking either button below.

.. grid:: 1 2 3 4

    .. grid-item::

        .. button-link:: https://github.com/collective/icalendar/issues?q=is%3Aissue%20state%3Aopen%20label%3A%22doc%22
            :color: success
            :shadow:

            Documentation

    .. grid-item::

        .. button-link:: https://github.com/collective/icalendar/issues?q=is%3Aissue%20state%3Aopen%20label%3A%22good%20first%20issue%22
            :color: primary
            :shadow:

            Good First Issue


Contents
--------

.. toctree::
    :maxdepth: 2

    small-edits
    build-check
    style-guide
